@@ -112,60 +112,3 @@ class GroupTypes:
     DonutSubscriptionPriceChanged = DonutSubscriptionPriceChanged
     DonutMoneyWithdraw = DonutMoneyWithdraw
     DonutMoneyWithdrawError = DonutMoneyWithdrawError
-
-    UnifiedTypes = Union[
-        BaseGroupEvent,
-        MessageNew,
-        MessageReply,
-        MessageEdit,
-        MessageAllow,
-        MessageDeny,
-        MessageTypingState,
-        MessageEvent,
-        PhotoNew,
-        PhotoCommentNew,
-        PhotoCommentEdit,
-        PhotoCommentRestore,
-        PhotoCommentDelete,
-        AudioNew,
-        VideoNew,
-        VideoCommentNew,
-        VideoCommentEdit,
-        VideoCommentRestore,
-        VideoCommentDelete,
-        WallPostNew,
-        WallRepost,
-        WallReplyNew,
-        WallReplyEdit,
-        WallReplyRestore,
-        WallReplyDelete,
-        LikeAdd,
-        LikeRemove,
-        BoardPostNew,
-        BoardPostEdit,
-        BoardPostRestore,
-        BoardPostDelete,
-        MarketCommentNew,
-        MarketCommentEdit,
-        MarketCommentRestore,
-        MarketCommentDelete,
-        MarketOrderNew,
-        MarketOrderEdit,
-        GroupLeave,
-        GroupJoin,
-        UserBlock,
-        UserUnblock,
-        PollVoteNew,
-        GroupOfficersEdit,
-        GroupChangeSettings,
-        GroupChangePhoto,
-        VkpayTransaction,
-        AppPayload,
-        DonutSubscriptionCreate,
-        DonutSubscriptionProlonged,
-        DonutSubscriptionExpired,
-        DonutSubscriptionCancelled,
-        DonutSubscriptionPriceChanged,
-        DonutMoneyWithdraw,
-        DonutMoneyWithdrawError,
-    ]
