@@ -323,6 +323,8 @@ class DonutMoneyWithdrawErrorObject(BaseEventObject):
     reason: str
 
 
-for item in locals().copy().values():
+_locals = locals().copy()
+_locals_values = _locals.values()
+for item in _locals_values:
     if inspect.isclass(item) and issubclass(item, BaseEventObject):
         item.update_forward_refs()
