@@ -3,9 +3,8 @@ import inspect
 from enum import Enum
 from typing import List, Optional
 
-from vkbottle_types.codegen.objects import *  # noqa: F403,F401
-
 from vkbottle_types.base_model import BaseModel
+from vkbottle_types.codegen.objects import *  # noqa: F403,F401
 
 
 class MessagesMessageActionStatus(Enum):
@@ -45,6 +44,7 @@ class MessagesMessageAttachmentType(Enum):
     GROUP_CALL_IN_PROGRESS = (
         "group_call_in_progress"  # https://github.com/VKCOM/vk-api-schema/issues/225
     )
+    MINI_APP = "mini_app"
 
 
 class VideoVideoType(Enum):
@@ -52,6 +52,7 @@ class VideoVideoType(Enum):
     MUSIC_VIDEO = "music_video"
     MOVIE = "movie"
     SHORT_VIDEO = "short_video"  # https://github.com/VKCOM/vk-api-schema/issues/212
+    LIVE = "live"  # https://github.com/VKCOM/vk-api-schema/issues/230
 
 
 class BaseLinkButtonActionType(Enum):
@@ -85,6 +86,7 @@ class MessagesMessageAttachment(MessagesMessageAttachment):
     group_call_in_progress: Optional["GroupCallInProgress"] = None
     link: Optional["BaseLinkAttachment"] = None
     wall: Optional["WallWallpostFull"] = None
+    mini_app: Optional[dict] = None
     type: "MessagesMessageAttachmentType"
 
 
@@ -99,6 +101,17 @@ class LinkPhoto(PhotosPhoto):
     date: Optional[int] = None
 
 
+class PhotosPhotoAlbumFull(PhotosPhotoAlbumFull):
+    # https://github.com/VKCOM/vk-api-schema/issues/228
+    created: Optional[int] = None
+    updated: Optional[int] = None
+
+
+class PhotosPhoto(PhotosPhoto):
+    # https://github.com/VKCOM/vk-api-schema/issues/229
+    has_tags: Optional[bool] = None
+
+
 class MessagesMessage(MessagesMessage):
     # https://github.com/VKCOM/vk-api-schema/issues/225
     attachments: Optional[List["MessagesMessageAttachment"]] = None
